@@ -1,4 +1,3 @@
-
 use v5.14;
 use UAV::Pilot::Exceptions;
 use UAV::Pilot::Video::FileDump;
@@ -223,7 +222,6 @@ sub record_usb ()
         return 1;
     };
     my $start_video_external_process_fileno = sub {
-        my ($out_file) = @_;
         $init_events->();
 
         $vid_driver = UAV::Pilot::ARDrone::Video::Fileno->new({
@@ -233,10 +231,7 @@ sub record_usb ()
         my $fileno = $vid_driver->fileno;
 
         $SIG{CHLD} = 'IGNORE';
-        my @exec = ( VIDEO_EXTERNAL_STREAM_EXEC,
-            '--fileno='   . $fileno,
-            (defined $out_file ? '--out-file=' . $out_file : ()),
-        );
+        my @exec = ( VIDEO_EXTERNAL_STREAM_EXEC, '--fileno=' . $fileno );
         my $pid = 'MSWin32' eq $^O
             ? $fork_process_win32->( @exec )
             : $fork_process_unixy->( @exec );
@@ -309,15 +304,15 @@ sub record_usb ()
         return 1;
     }
 
-    sub start_video (;$$)
+    sub start_video (;$)
     {
-        my ($type, $out_file) = @_;
+        my ($type) = @_;
         $type //= 0;
 
         return
-            (0 == $type) ?$start_video_external_process_fileno->($out_file):
-            (1 == $type) ? $start_video_external_process->( $out_file ) :
-            $start_video_single_process->( $out_file );
+            (0 == $type) ? $start_video_external_process_fileno->() :
+            (1 == $type) ? $start_video_external_process->() :
+            $start_video_single_process->();
     }
 
     sub dump_video_to_file ($)
